@@ -49,13 +49,11 @@ function(xy, level=0.5, dstTarget=100, conversion="m2cm", doRob=TRUE) {
     flat   <- 1 - (1/aspRat)             # flattening
     shape  <- c(aspectRatio=aspRat, flattening=flat, trace=trXY, det=detXY)
 
-    if(nrow(xy) < 4) {
-        haveRob <- FALSE
-        if(doRob) {
-            warning("We need >= 4 points for robust estimations")
-        }
+    haveRob <- if(nrow(xy) < 4) {
+        if(doRob) { warning("We need >= 4 points for robust estimations") }
+        FALSE
     } else {
-        haveRob <- TRUE
+        TRUE
     }                                    # if(nrow(xy) < 4)
 
     if(doRob && haveRob) {               # same for robust estimation
